@@ -1,18 +1,14 @@
 import pickle
+from datetime import datetime
 from typing import List, Union
 
 import pydash
 import pytest
-from _pytest.config import ExitCode, Config
-from _pytest.main import Session
-from _pytest.mark import Mark
-from _pytest.nodes import Item
-from _pytest.reports import TestReport
-from _pytest.runner import CallInfo
+from pytest import ExitCode, Config, Session, Mark, Item, TestReport, CallInfo
 
 from .config import TrConfig
 from .constants import TR_MARKER_NAME, TR_PASSED_TESTS_FLUSH_SIZE, TestrailStatus, \
-    PytestStatus, TESTRAIL_STATUS_PRIORITY, PYTEST_TO_TESTRAIL_STATUS
+    PytestStatus, TESTRAIL_STATUS_PRIORITY, PYTEST_TO_TESTRAIL_STATUS, TestrailMsgStyle
 from .dto import ReportDTO
 from .service import TrService
 
@@ -92,10 +88,19 @@ class TrClient:
         else:
             if not self._service.is_test_run_available():
                 # Todo: Probably it would be better to create new test run after all tests are collected.
-                self._service.create_test_run(self._service.get_cases())
+                config = session.config
+                run_name = config.hook.pytest_tr_generate_run_name(config=config)
+                actual_cases = {x.case_id for x in self._results}
+                self._service.create_test_run(run_name, actual_cases)
 
             self._service.upload_results(self._prepare_report(self._results, self._service.get_cases()))
 
+    @pytest.hookimpl(trylast=True)
+    def pytest_tr_generate_run_name(self, config):
+        """Default tr run name generation."""
+        current_date = datetime.now().utcnow().strftime("%d-%h-%y %H:%MUTC")
+        return 'Automated test run ' + current_date
+
     def pytest_testnodedown(self, node, error):
         """
         Extend master node results with worker's node results.
@@ -130,11 +135,24 @@ class TrClient:
             msg = f"Test ID: {msg[msg.find('[') + 1: msg.find(']')]}"
 
         if report.status == PytestStatus.FAILED:
-            return f'{msg}\n{pydash.get(report, "longrepr.reprcrash.message"), ""}'
+            tb = f'{msg}\n{pydash.get(report, "longrepr.reprcrash.message", "")}'
+            if self._tr_config.tb_style == TestrailMsgStyle.LONG:
+                return tb
+            elif self._tr_config.tb_style == TestrailMsgStyle.SHORT:
+                return self._shorten_error(tb)
         if report.status == PytestStatus.SKIPPED:
             return msg + f'\n{pydash.get(report, "longrepr[2]", "")}'
         return msg
 
+    @staticmethod
+    def _shorten_error(err: str) -> str:
+        """Cuts long traceback message."""
+        if not err:
+            return err
+
+        cut_until = err.find('\n + ')  # May be changed to more accurate substr
+        return err[:cut_until]
+
     @staticmethod
     def __is_parametrized_test(markers: List[Mark]):
         """
